Struct GetAutocmdsOptsBuilder
pub struct GetAutocmdsOptsBuilder(GetAutocmdsOpts);Tuple Fields
0: GetAutocmdsOptsImplementations
impl GetAutocmdsOptsBuilder
impl GetAutocmdsOptsBuilder
pub fn buffer(&mut self, buffer: Buffer) -> &mut GetAutocmdsOptsBuilder
pub fn buffer(&mut self, buffer: Buffer) -> &mut GetAutocmdsOptsBuilder
Get the autocommands local to a specific Buffer. Cannot be used
pub fn events<'a, E>(&mut self, events: E) -> &mut GetAutocmdsOptsBuilderwhere
E: IntoIterator<Item = &'a str>,
pub fn events<'a, E>(&mut self, events: E) -> &mut GetAutocmdsOptsBuilderwhere
E: IntoIterator<Item = &'a str>,
Get all the autocommands triggered by one or more of the specified
pub fn group<G>(&mut self, group: G) -> &mut GetAutocmdsOptsBuilderwhere
G: StringOrInt,
pub fn group<G>(&mut self, group: G) -> &mut GetAutocmdsOptsBuilderwhere
G: StringOrInt,
Only get the autocommands belonging to a specific augroup. The
pub fn patterns<'a, P>(&mut self, patterns: P) -> &mut GetAutocmdsOptsBuilderwhere
P: IntoIterator<Item = &'a str>,
pub fn patterns<'a, P>(&mut self, patterns: P) -> &mut GetAutocmdsOptsBuilderwhere
P: IntoIterator<Item = &'a str>,
Only get the autocommands that match specific patterns. For example, if
pub fn build(&mut self) -> GetAutocmdsOpts